@@ -1,6 +1,7 @@
 import sys
 import time
 import splight_models as spmodels
+import uuid
 from functools import partial
 from abc import abstractmethod
 from tempfile import NamedTemporaryFile
@@ -22,16 +23,52 @@ from splight_models import (
     ComponentObject,
     Boolean,
     String,
-    Number
+    Number,
+    Secret
 )
 from splight_models.component import EventNames, ComponentCommandUpdateEvent, ComponentCommandTriggerEvent, CommunicationEvent
 from splight_models.component import ComponentCommand, ComponentCommandStatus
-from splight_models.component import DATABASE_TYPES, NATIVE_TYPES, STORAGE_TYPES, Parameter
+from splight_models.component import (
+    DATABASE_TYPES,
+    NATIVE_TYPES,
+    Parameter,
+    InputParameter
+)
+import re
 
 
 logger = logging.getLogger()
 
 
+class SecretValueParser:
+
+    def __init__(self, utils, *args, **kwargs):
+        self.utils = utils
+
+    def get_value(self, name: str) -> Any:
+        secret = self.utils.database_client.get(Secret, name=name, first=True)
+        return secret.decrypt()
+
+
+class VariableValueMixin:
+    _variable_parameter_map_class = {
+        'SECRET': SecretValueParser,
+    }
+
+    def parse_variable_string(self, value: str) -> Any:
+        pattern = re.compile(r"^\$\{\{(\w+)\.(\w+)\}\}$")
+        match = pattern.search(value)
+        if not match:
+            return value
+        class_key, name = match.groups()
+        try:
+            parser_class = self._variable_parameter_map_class[class_key]
+        except KeyError as e:
+            raise NotImplementedError(f"Variable {class_key} is not supported yet.") from e
+
+        return parser_class(utils=self).get_value(name)
+
+
 class RunnableMixin:
     healthcheck_interval = 5
     _HEALTH_FILE_PREFIX = "healthy_"
@@ -130,7 +167,6 @@ class HooksMixin:
         kwargs["dataframe"] = dataframe
         return args, kwargs
 
-
     def __hook_transform_from_custom_resource_type(self, *args, **kwargs):
         resource_type = kwargs["resource_type"]
         if resource_type and hasattr(self.custom_types, resource_type.__name__):
@@ -203,7 +239,7 @@ class BindingsMixin:
         component_object: ComponentObject = ComponentObject(**component_object_event.data)
         custom_object_data = component_object.data
         custom_object_data.extend([
-            Parameter(name=key, value=getattr(component_object, key))
+            InputParameter(name=key, value=getattr(component_object, key))
             for key in CustomType._reserved_names
         ])
         custom_object_model = getattr(self.custom_types, binding_object_type)
@@ -281,14 +317,16 @@ class ParametersMixin:
             type = parameter["type"]
             value = parameter["value"]
             multiple = parameter["multiple"]
-            if type in NATIVE_TYPES or type in DATABASE_TYPES or type in STORAGE_TYPES:
+            if type == 'str':
+                parameter["value"] = self.parse_variable_string(value)
+            if type in NATIVE_TYPES or type in DATABASE_TYPES:
                 parameter["value"] = value
             else:
                 object_ids = value if multiple else [value]
                 objects = self.database_client.get(ComponentObject, id__in=object_ids)
                 for o in objects:
                     component_object_data = [
-                        Parameter(name=key, value=getattr(o, key))
+                        InputParameter(name=key, value=getattr(o, key))
                         for key in CustomType._reserved_names
                     ]
                     o.data.extend(component_object_data)
@@ -299,8 +337,7 @@ class ParametersMixin:
 
     def _get_object_ids(self, parameters: List[Dict]) -> Dict[str, Dict[str, List]]:
         ids = {
-            "database": defaultdict(list),
-            "storage": defaultdict(list),
+            "database": defaultdict(list)
         }
         for parameter in parameters:
             parameter = parameter.dict() if not isinstance(parameter, dict) else parameter
@@ -312,9 +349,6 @@ class ParametersMixin:
             elif parameter["type"] in DATABASE_TYPES:
                 for value in values:
                     ids["database"][parameter["type"]].append(value)
-            elif parameter["type"] in STORAGE_TYPES:
-                for value in values:
-                    ids["storage"][parameter["type"]].append(value)
             else:
                 for value in values:
                     ids = merge(ids, self._get_object_ids(value), strategy=mergeStrategy.ADDITIVE)
@@ -327,10 +361,6 @@ class ParametersMixin:
         for type, ids_ in ids_to_fetch["database"].items():
             objs = self.database_client.get(DATABASE_TYPES[type], id__in=ids_)
             res.update({obj.id: obj for obj in objs})
-
-        for type, ids_ in ids_to_fetch["storage"].items():
-            objs = self.storage_client.get(STORAGE_TYPES[type], id__in=ids_)
-            res.update({obj.id: obj for obj in objs})
         return res
 
     def _reload_parameters(self, parameters: List[Dict], objects: Dict) -> List[Dict]:
@@ -341,9 +371,11 @@ class ParametersMixin:
             type = parameter["type"]
             value = parameter["value"]
             multiple = parameter["multiple"]
-            if type in NATIVE_TYPES or value is None:
+            if type == 'str':
+                parameter["value"] = self.parse_variable_string(value)
+            elif type in NATIVE_TYPES or value is None:
                 parameter["value"] = value
-            elif type in DATABASE_TYPES or type in STORAGE_TYPES:
+            elif type in DATABASE_TYPES:
                 parameter["value"] = [objects[val] for val in value] if multiple else objects[value]
             else:
                 parameter["value"] = [self._reload_parameters(value, objects) for value in value] if multiple else self._reload_parameters(value, objects)
@@ -363,29 +395,28 @@ class ParametersMixin:
 
             if type in NATIVE_TYPES:
                 parameters_dict[name] = value
-            elif type in DATABASE_TYPES or type in STORAGE_TYPES:
+            elif type in DATABASE_TYPES:
                 parameters_dict[name] = value
             else:
                 parameters_dict[name] = [self._transform_parameters(val) for val in value] if multiple else self._transform_parameters(value)
         return parameters_dict
 
 
-class AbstractComponent(RunnableMixin, HooksMixin, IndexMixin, BindingsMixin, ParametersMixin):
+class AbstractComponent(RunnableMixin, HooksMixin, IndexMixin, BindingsMixin, ParametersMixin, VariableValueMixin):
     database_client_kwargs: Dict[str, Any] = {}
     datalake_client_kwargs: Dict[str, Any] = {}
     deployment_client_kwargs: Dict[str, Any] = {}
-    storage_client_kwargs: Dict[str, Any] = {}
     communication_client_kwargs: Dict[str, Any] = {}
     blockchain_client_kwargs: Dict[str, Any] = {}
 
-    def __init__(self, run_spec: dict, initial_setup: Optional[dict] = None, *args, **kwargs):
+    def __init__(self, run_spec: dict, initial_setup: Optional[dict] = None, component_id: str = None, *args, **kwargs):
         self._setup = default_setup
         if initial_setup:
             self._setup.configure(initial_setup)
 
         self.namespace = self._setup.settings.NAMESPACE
-        self.instance_id = self._setup.settings.COMPONENT_ID
         self.instance_type = Component
+        self.instance_id = component_id if component_id else str(uuid.uuid4())
         self.deployment_id = run_spec.pop("id", None)
 
         self._spec: Deployment = Deployment(id=self.instance_id, **run_spec)
@@ -439,10 +470,6 @@ class AbstractComponent(RunnableMixin, HooksMixin, IndexMixin, BindingsMixin, Pa
             namespace=self.namespace,
             **self.deployment_client_kwargs
         )
-        self.storage_client = self.setup.STORAGE_CLIENT(
-            namespace=self.namespace,
-            **self.storage_client_kwargs
-        )
         self.communication_client = self.setup.COMMUNICATION_CLIENT(
             namespace=self.namespace,
             **self.communication_client_kwargs
