@@ -7,18 +7,13 @@ from splight_models.credential import *
 from splight_models.datalake import *
 from splight_models.deployment import *
 from splight_models.file import *
-from splight_models.geopoint import *
 from splight_models.graph import *
 from splight_models.hub import *
-from splight_models.mapping import *
-from splight_models.message import *
 from splight_models.namespace import *
-from splight_models.network import *
 from splight_models.notification import *
-from splight_models.tag import *
 from splight_models.query import *
 from splight_models.component import *
-from splight_models.storage import *
-from splight_models.tag import *
 from splight_models.user import *
 from splight_models.variable import *
+from splight_models.webhook import *
+from splight_models.secret import *
