@@ -3,7 +3,6 @@ from enum import Enum
 from typing import Dict, Optional
 from pydantic import Field
 from splight_models.base import SplightBaseModel
-from splight_models.mapping import Mapping
 from splight_models.user import User
 from datetime import datetime, timezone
 
@@ -22,9 +21,7 @@ class EventNames(str, Enum):
     COMPONENT_COMMAND_CREATE = 'componentcommand-create'
     COMPONENT_COMMAND_UPDATE = 'componentcommand-update'
     # TODO add Asset Attribute and all shared objects
-    # TODO delete these
-    MAPPING_CREATE = "mapping-create"
-    MAPPING_DELETE = "mapping-delete"
+
 
 class CommunicationEvent(SplightBaseModel):
     event_name: str
@@ -35,14 +32,3 @@ class CommunicationEvent(SplightBaseModel):
     display_text: Optional[str] = None
     user: Optional[User] = None
     data: Dict
-
-
-# TODO remove all this
-class MappingCreateEvent(CommunicationEvent):
-    event_name: str = Field(EventNames.MAPPING_CREATE, const=True)
-    data: Mapping
-
-
-class MappingDeleteEvent(CommunicationEvent):
-    event_name: str = Field(EventNames.MAPPING_DELETE, const=True)
-    data: Mapping
