@@ -9,7 +9,6 @@ VERIFICATION_CHOICES = ['verified', 'unverified', 'official']
 class HubComponent(BaseComponent):
     id: Optional[str]
     name: str
-    type: str = "Component"
     splight_cli_version: str
     build_status: Optional[str]
     description: Optional[str]
@@ -22,6 +21,8 @@ class HubComponent(BaseComponent):
     created_at: Optional[str]
     last_modified: Optional[str]
     tags: List[str] = []
+    min_component_capacity: Optional[str]
+    usage_count: int = 0
 
     @validator('verification', pre=True, always=True)
     def set_verification_now(cls, v):
